@@ -7,6 +7,11 @@ class NuException(Exception):
         super().__init__(message)
 
 
+class NuMissingCreditCard(NuException):
+    def __init__(self):
+        super().__init__(f'Couldn\'t fetch bills due to missing credit card.')
+
+
 class NuRequestException(NuException):
     def __init__(self, response: Response):
         super().__init__(f'The request made failed with HTTP status code {response.status_code}')
