@@ -17,10 +17,13 @@ class HttpClient:
     def set_cert(self, cert_path: str):
         self._cert = cert_path
 
-    def set_header(self, name, value):
+    def set_header(self, name: str, value: str):
         self._headers[name] = value
 
-    def get_header(self, name):
+    def remove_header(self, name: str):
+        self._headers.pop(name)
+
+    def get_header(self, name: str):
         return self._headers.get(name)
 
     @property
@@ -33,8 +36,11 @@ class HttpClient:
 
         return response.json()
 
+    def raw_get(self, url: str) -> Response:
+        return get(url, headers=self._headers, **self._cert_args)
+
     def get(self, url: str) -> dict:
-        return self._handle_response(get(url, headers=self._headers, **self._cert_args))
+        return self._handle_response(self.raw_get(url))
 
     def post(self, url: str, json: dict) -> dict:
         return self._handle_response(post(url, json=json, headers=self._headers, **self._cert_args))
